@@ -26,6 +26,7 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
+#include <gtksourceview/gtksourcetypes.h>
 #include <gtksourceview/gtksourcegutterrenderer.h>
 
 G_BEGIN_DECLS
@@ -37,7 +38,6 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_IS_GUTTER_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_SOURCE_TYPE_GUTTER))
 #define GTK_SOURCE_GUTTER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_SOURCE_TYPE_GUTTER, GtkSourceGutterClass))
 
-typedef struct _GtkSourceGutter			GtkSourceGutter;
 typedef struct _GtkSourceGutterClass	GtkSourceGutterClass;
 typedef struct _GtkSourceGutterPrivate	GtkSourceGutterPrivate;
 
